Ambric.point_estimates_q_on_4q()

Produce a table of nowcast point estimates by region.

Usage

Ambric.point_estimates_q_on_4q(path=None)

Returns q-on-4q annual growth estimates (in percentage points, rounded to 2 d.p.) at quarterly frequency.

Parameters

path: Path | None = None

Directory to save the table as Parquet. When None no file is written.

Raises

ValueError

If model not fitted.

Returns

pd.DataFrame

pd.DataFrame: Wide-format table with datetime index and one column per region containing the point estimate.