diagnostics.plot_out_of_sample_nowcasts()

Plot out-of-sample nowcasts vs outturns for each region.

Usage

diagnostics.plot_out_of_sample_nowcasts(
    df_results,
    region_measure,
    path=None,
)

Produces one figure per region showing observed outturns as dots and nowcasts at varying horizons with transparency indicating proximity to publication.

Parameters

df_results: pd.DataFrame

Out-of-sample results from ~ambric.run_out_of_sample_exercise().

region_measure: str

Regional measure name to filter on.

path: Path | None = None

Directory to save the figures. When None the figures are displayed interactively.